@@ -2,6 +2,7 @@ from pprint import pprint
 import tensorflow as tf
 from tensorflow.keras import layers
 from . import xception as xcpt
+from . import base
 from . import blocks
 from . import load
 #
@@ -25,6 +26,7 @@ class DLV3p(tf.keras.Model):
     DEFAULTS=load.config(cfig='dlv3p',key_path=DEFAULT_KEY)
     BEFORE_UP='before'
     AFTER_UP='after'
+    UPSAMPLE_MODE='bilinear'
     #
     # STATIC
     #
@@ -105,7 +107,7 @@ class DLV3p(tf.keras.Model):
             backbone_name=DEFAULTS.get('backbone_name',True),
             name=DEFAULTS.get('name',None),
             named_layers=DEFAULTS.get('named_layers',True),
-            **step_kwargs):
+            **kwargs):
         super(DLV3p, self).__init__()
         self.model_name=name
         self.named_layers=named_layers
@@ -261,7 +263,7 @@ class DLV3p(tf.keras.Model):
             index=None,
             config={}):
         if filters:
-            return blocks.CBAD(
+            return blocks.Conv(
                     filters=filters,
                     kernel_size=kernel_size,
                     name=self._layer_name(group,index=index),
